﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using C1.Silverlight;
using C1.Silverlight.Chart;
using C1.Silverlight.Toolbar;
using System.Windows.Controls.Primitives;

namespace ToolbarCommands.ViewModel
{
    public class MainPageViewModel : ViewModelBase
    {
        #region Constructor
        public MainPageViewModel()
        {
            this.MainChartType = ChartType.Column;
            this.LineChartType = ChartType.Line;
            this.AreaChartType = ChartType.Area;
            this.ColumnChartType = ChartType.Column;
            this.PieChartType = ChartType.Pie;
            this.LegendVisibility = Visibility.Visible;
        }

        #endregion
      
        #region Object model

        private ChartType _mainChartType;
        public ChartType MainChartType
        {
            get
            {
                return _mainChartType;
            }
            set
            {
                _mainChartType = value;
                //Fire property changed
                this.OnPropertyChanged("MainChartType");
            }
        }

        private Visibility _legendVisibility;
        public Visibility LegendVisibility
        {
            get
            {
                return _legendVisibility;
            }
            set
            {
                _legendVisibility = value;
                //Fire property changed
                this.OnPropertyChanged("LegendVisibility");
            }
        }

        public ChartType ColumnChartType { get; set; }
        public ChartType AreaChartType { get; set; }
        public ChartType LineChartType { get; set; }
        public ChartType PieChartType { get; set; }

        #endregion

        #region Commands
        static MainPageViewModel()
        {
            // register class commands in a static constructor

            // register ChartType command
            CommandManager.RegisterClassCommandBinding(typeof(MainPageViewModel), new CommandBinding(ChartTypeCommand, SetChartType));
            // register legend visibility command
            CommandManager.RegisterClassCommandBinding(typeof(MainPageViewModel), new CommandBinding(ToggleLegendCommand, ToggleLegend));
        }

        // ChartType command
        public static readonly C1Command ChartTypeCommand =
            new C1Command("ChartType", typeof(MainPageViewModel));

        // ToggleLegend command
        public static readonly C1Command ToggleLegendCommand =
          new C1Command("ToggleLegend", typeof(MainPageViewModel));

        private static void SetChartType(object sender, ExecutedRoutedEventArgs e)
        {
            // get command target from the sender's DataContext
            ButtonBase btn = sender as ButtonBase;
            if (btn != null)
            {
                MainPageViewModel viewModel = btn.DataContext as MainPageViewModel;
                if (viewModel != null && e.Parameter != null)
                {
                    // handle ChartType command
                    viewModel.MainChartType = (ChartType)e.Parameter;
                }
            }
        }

        private static void ToggleLegend(object sender, ExecutedRoutedEventArgs e)
        {
            // get command target from the sender's DataContext
            ButtonBase btn = sender as ButtonBase;
             if (btn != null)
             {
                 MainPageViewModel viewModel = btn.DataContext as MainPageViewModel;
                 if (viewModel != null)
                 {
                     // handle ToggleLegend command
                     bool param = (bool)e.Parameter;
                     if (param)
                     {
                         viewModel.LegendVisibility = Visibility.Visible;
                     }
                     else
                     {
                         viewModel.LegendVisibility = Visibility.Collapsed;
                     }
                 }
             }
        }

        #endregion
    }
}
